@@ -9,7 +9,7 @@ our @EXPORT = qw( alien_diag );
 our @EXPORT_OK = @EXPORT;
 
 # ABSTRACT: Print out standard diagnostic for Aliens in the test step.
-our $VERSION = '1.90'; # VERSION
+our $VERSION = '1.91'; # VERSION
 
 
 sub alien_diag ($@)
@@ -50,7 +50,9 @@ sub alien_diag ($@)
       if(eval { $alien->can($name) })
       {
         $found++;
-        $ctx->diag(sprintf "%-${max}s = %s", "$alien->$name", $_) for $alien->$name;
+        my @list = eval { $alien->$name };
+        next if $@;
+        $ctx->diag(sprintf "%-${max}s = %s", "$alien->$name", $_) for @list;
       }
     }
 
@@ -76,7 +78,7 @@ Test::Alien::Diag - Print out standard diagnostic for Aliens in the test step.
 
 =head1 VERSION
 
-version 1.90
+version 1.91
 
 =head1 SYNOPSIS
 
